@@ -9,7 +9,7 @@
 using namespace Rcpp;
 using namespace RcppParallel;
 
-unsigned char N0[256] = {
+uint8_t N0[256] = {
 4, 3, 3, 3, 3, 2, 2, 2, 3, 2, 2, 2, 3, 2, 2, 2, 
 3, 2, 2, 2, 2, 1, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 
 3, 2, 2, 2, 2, 1, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 
@@ -27,7 +27,7 @@ unsigned char N0[256] = {
 2, 1, 1, 1, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 
 2, 1, 1, 1, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0};
 
-unsigned char N1[256] = {
+uint8_t N1[256] = {
 0, 1, 0, 0, 1, 2, 1, 1, 0, 1, 0, 0, 0, 1, 0, 0, 
 1, 2, 1, 1, 2, 3, 2, 2, 1, 2, 1, 1, 1, 2, 1, 1, 
 0, 1, 0, 0, 1, 2, 1, 1, 0, 1, 0, 0, 0, 1, 0, 0, 
@@ -55,7 +55,7 @@ List geno_stats(matrix4 & A) {
 
   for(size_t i = 0; i < A.nrow; i++) {
     for(size_t j = 0; j < A.true_ncol; j++) {
-      unsigned char d = (unsigned char) A.data[i][j];
+      uint8_t d = A.data[i][j];
       SN(0,i) += N0[d];
       SN(3,i) += N0[255-d];
       SN(1,i) += N1[d];
@@ -86,7 +86,7 @@ DataFrame geno_stats_snp(matrix4 & A) {
 
   for(size_t i = 0; i < A.nrow; i++) {
     for(size_t j = 0; j < A.true_ncol; j++) {
-      unsigned char d = (unsigned char) A.data[i][j];
+      uint8_t d = A.data[i][j];
       SN(0,i) += N0[d];
       SN(3,i) += N0[255-d];
       SN(1,i) += N1[d];
@@ -106,7 +106,7 @@ DataFrame geno_stats_ind(matrix4 & A) {
 
   for(size_t i = 0; i < A.nrow; i++) {
     for(size_t j = 0; j < A.true_ncol; j++) {
-      unsigned char d = (unsigned char) A.data[i][j];
+      uint8_t d = A.data[i][j];
       pIN[16*j + ((int) d&3)]++;
       pIN[16*j + 4  + ((int) (d>>2)&3)]++;
       pIN[16*j + 8  + ((int) (d>>4)&3)]++;
